@@ -1,4 +1,4 @@
 """Implementation of the mysql server wire protocol"""
-from mysql_mimic.result import ResultColumn, ResultSet
+from mysql_mimic.results import ResultColumn, ResultSet
 from mysql_mimic.session import Session
 from mysql_mimic.server import MysqlServer
